@@ -18,7 +18,7 @@ mkdir_ = libc.func("i", "mkdir", "si")
 rename_ = libc.func("i", "rename", "ss")
 unlink_ = libc.func("i", "unlink", "s")
 rmdir_ = libc.func("i", "rmdir", "s")
-getwd_ = libc.func("s", "getwd", "s")
+getcwd_ = libc.func("s", "getcwd", "si")
 opendir_ = libc.func("P", "opendir", "s")
 readdir_ = libc.func("P", "readdir", "P")
 read_ = libc.func("i", "read", "ipi")
@@ -56,7 +56,7 @@ def raise_error():
 
 def getcwd():
     buf = bytearray(512)
-    return getwd_(buf)
+    return getcwd_(buf, 512)
 
 def mkdir(name, mode=0o777):
     e = mkdir_(name, mode)
